Learn R Programming

argoFloats (version 1.0.9)

show,argoFloats-method: Show Information About argoFloats Object

Description

This produces a one-line explanation of the contents of the object, that typically indicates the type and the number of items referenced by the object. Those items depend on the type of object: URLs if metadata$type is "index", local filenames if "profiles", or oce-created argo objects if "argos". As with other R show() methods, it may be invoked in an interactive session just by typing the object, or by using print(); see the Examples.

Usage

# S4 method for argoFloats
show(object)

Value

None (invisible NULL).

Arguments

object

an argoFloats object.

Author

Jaimie Harbin

Examples

Run this code
library(argoFloats)
data(index)
show(index)
print(index)
index

Run the code above in your browser using DataLab