This produces a one-line explanation of the contents of the object,
that typically indicates the type and the number of items referenced
by the object. Those items depend on the type of object:
URLs if metadata$type is "index", local filenames if
"profiles", or oce-created argo objects if "argos".
As with other R show() methods, it may be invoked in an interactive
session just by typing the object, or by using print(); see the Examples.